# A file for a data frame has
# The first line are column labels (separated by whitespace)
# the remaining lines start with a row label,
# so they have one more column than the number
# of column labels.
# Watch out for the default comment character='#'.
# To read in sentences_bitones.txt, do this:
readline(prompt="<Read in the data table>")
f = read.table("data/sentences_bitones.txt", comment.char="")
summary(f)
# Tone1         Tone2    
# BOF    :924   EOF    :924  
# %      :815   %      :815  
# H*L    :805   H*L    :805  
# H*     :626   H*     :626  
# L*H    :404   L*H    :404  
# !H*L   :185   !H*L   :185  
# (Other):229   (Other):229 
readline(prompt="<show the Tone1 data>")
f$Tone1
# ...
# [3809] H*   H*L  %    BOF  H*   H*   L*H  %    BOF  H*   H*L  H%   BOF  L*  
# [3823] L*H  %    BOF  H*   L*H  %    BOF  H*   L*H  %    BOF  H*   H*   H%  
# ...
# Levels: !H* !H*L # % %H *? BOF H% H* H*L L% L* L*H
#
# The numbers in square brackets tell you where you are in a long
# vector.   This particular vector has 3988 entries.
readline(prompt="<attach, show Tone1 again>")
attach(f)
Tone1
# ...
# [3809] H*   H*L  %    BOF  H*   H*   L*H  %    BOF  H*   H*L  H%   BOF  L*
# [3823] L*H  %    BOF  H*   L*H  %    BOF  H*   L*H  %    BOF  H*   H*   H%
# ...
# Levels: !H* !H*L # % %H *? BOF H% H* H*L L% L* L*H
# 
# We can look at just a few of the tones by selecting
# a range.
readline(prompt="<show a small amount of Tone1>")
Tone1[1:10]
# [1] BOF L*H L*H %   BOF H*  !H* L*H L*H %  
# Levels: !H* !H*L # % %H *? BOF H% H* H*L L% L* L*H
#
readline(prompt="<show the first 30 tones in Tone1>")
Tone1[1:30]
# [1] BOF L*H L*H %   BOF H*  !H* L*H L*H %   BOF H*L L*H H*L %   BOF H*  L*H L*H
# [20] %   BOF L*  L*H L*H %   BOF H*  L*H L*H %  
# Levels: !H* !H*L # % %H *? BOF H% H* H*L L% L* L*H
# 
# The [20] tells us that the 20th entry in the Tone 1 vector is
# at the beginning of the second line of output, and it is "%".
#
# Now, we can look for pairings of tones using this
# strange but logical syntax:
readline(prompt="<show Tone2 whenever Tone1 is L*H>")
Tone2[Tone1=="L*H"]
# ...
# [136] %    %    %    %    %    %    %    %    %    %    %    L*H  %    %    L*H 
# [151] %    %    %    %    L*   %    %    %    %    %    L*H  %    L*H  %    %   
# [166] L*H  H%   %    %    L*H  %    L*H  %    %    H*L  H*L  !H*L L*H  L*H  %   
# ...
# [391] %    %    H*L  %    %    %    H*L  %    %    %    L*H  !H*L %    H*L 
# Levels: !H* !H*L # % %H *? EOF H% H* H*L L% L* L*H
# 
# That tells us that "L*H" is often followed by "%", and the last
# line ("Levels:") tells us the complete set of possibilities that
# can follow a L*H accent.
# 
# We can count the length of that vector:
readline(prompt="<How long is it?>")
length(Tone2[Tone1=="L*H"])
# [1] 404
# 
# 
# But, watch out!  You might guess that length(Tone1=="L*H") is also 404,
# but not so.    The expression Tone1=="L*H" is a vector of true/false
# values that is as long as the Tone1 vector:  3988 entries.
readline(prompt="<How long is Tone1?>")
length(Tone1=="L*H")
# [1] 3988
readline(prompt="<Which entries of Tone1==L*H?>")
Tone1=="L*H"
# ...
# [3961]  TRUE FALSE FALSE FALSE  TRUE FALSE FALSE FALSE FALSE FALSE FALSE  TRUE
# [ 3973]  TRUE FALSE FALSE FALSE FALSE  TRUE FALSE FALSE  TRUE FALSE FALSE FALSE
# [3985] FALSE FALSE FALSE FALSE
# 
# Another easy thing to do is find out what fraction of the
# data is a particular tone like L*H:
readline(prompt="<What is the frequency of L*H?>")
mean(Tone1=="L*H")
# [1] 0.1013039
# So, 10% of the tones are L*H.
# This works because TRUE counts as 1 and FALSE is also zero.
# 
# We can get more complicated here, looking at what tone
# follows a L*H, like this:
readline(prompt="<What is the frequency that Tone2=% when Tone1=L*H?>")
mean(Tone2[Tone1=="L*H"]=="%")
# [1] 0.5816832
# So, 58% of the time, a L*H is followed by a "%" (end of phrase
# without a major pitch motion) symbol.
#
# Create a table of frequencies:
readline(prompt="<What are the frequencies of the various combinations?>")
x = table(f)
x
#	Tone2
#Tone1  !H* !H*L   #   %  %H  *? EOF  H%  H* H*L  L%  L* L*H
#!H*    3   22   0   2   0   0   0   0   0   6   0   2  15
#!H*L   0    2   0 157   0   0   0  15   2   9   0   0   0
##      0    0   1   0   0   0   0   0   2   7   0   0   3
#%      0    0   0   0   0   0 806   0   0   6   0   0   3
#%H     0    0   0   0   0   0   0   0  10   3   0   0   1
#*?     0    0   0   0   0   0   0   0   1   0   0   0   0
#BOF    0    0   0   0  14   1   0   0 535 302   0   7  65
#H%     0    3   0   0   0   0 109   0   0   8   0   0   0
#H*    46  116   7   5   0   0   0  16  46 203   0  10 177
#H*L    1   39   4 416   0   0   0  43  26 207   0   2  67
#L%     0    0   0   0   0   0   9   0   0   0   0   0   0
#L*     0    0   0   0   0   0   0  12   1   3   0   0   6
#L*H    0    3   1 235   0   0   0  34   3  51   9   1  67
# 
#
# Now, we can plot that frequency table several ways:
readline(prompt="<mosaicplot?>")
mosaicplot(x, shade=TRUE, off=70)
# (Nifty plot produced in mosaicplot.png)
# The colors mark how big the entries are, relative
# to a simple statistical model where the
# Tone1 and Tone2 values are independent.
# In this example, they are not independent;
# while we won't go into the details of the model
# yet, there are strong correlations between
# neighbouring tones (as one might expect).
